ChatMessageAttachmentUploadDescription class abstract

A description for uploading an attachment.

Implemented types

Constructors

ChatMessageAttachmentUploadDescription({required String filePath, required String uploadDescription})
factory
ChatMessageAttachmentUploadDescription.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

filePath String
The path where the file should be uploaded.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uploadDescription String
The upload description, including any authentication keys required to do the upload.
getter/setter pair

Methods

copyWith({String? filePath, String? uploadDescription}) ChatMessageAttachmentUploadDescription
Returns a shallow copy of this ChatMessageAttachmentUploadDescription with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited