ChatMessagePost class abstract

A chat message post request.

Implemented types

Constructors

ChatMessagePost({required String channel, required String message, required int clientMessageId, List<ChatMessageAttachment>? attachments})
factory
ChatMessagePost.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

attachments List<ChatMessageAttachment>?
List of attachments associated with this message.
getter/setter pair
channel String
The channel this message is posted to.
getter/setter pair
clientMessageId int
The client id of the message, used to track message deliveries.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String
The body of the message.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? channel, String? message, int? clientMessageId, List<ChatMessageAttachment>? attachments}) ChatMessagePost
Returns a shallow copy of this ChatMessagePost with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited