DEPRECATED: This class is deprecated and will be removed in version 2.1. Please implement the SerializableModel interface instead for creating serializable models.
Migration Guide:
- Replace
extends SerializableEntitywithimplements SerializableModelin your model classes.
// Before:
class CustomClass extends SerializableEntity {
// Your code here
}
// After:
class CustomClass implements SerializableModel {
// Your code here
}
For more details, refer to the migration documentation
- Implemented types
- Annotations
-
- @Deprecated('This class is deprecated and will be removed in version 2.1. ' 'Please implement SerializableModel instead.')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → dynamic -
Returns a serialized JSON structure of the model which also includes
fields used by the database.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited